@@ -19,14 +19,14 @@ SEXP lookup(SEXP ux, SEXP xlen, SEXP indices, SEXP gaps, SEXP overlaps, SEXP mul
   if (!strcmp(CHAR(STRING_ELT(multArg, 0)), "all"))  mult = ALL;
   else if (!strcmp(CHAR(STRING_ELT(multArg, 0)), "first")) mult = FIRST;
   else if (!strcmp(CHAR(STRING_ELT(multArg, 0)), "last")) mult = LAST;
-  else error("Internal error: invalid value for 'mult'; this should have been caught before. please report to data.table issue tracker"); // # nocov
+  else error(_("Internal error: invalid value for 'mult'; this should have been caught before. please report to data.table issue tracker")); // # nocov
 
   if (!strcmp(CHAR(STRING_ELT(typeArg, 0)), "any"))  type = ANY;
   else if (!strcmp(CHAR(STRING_ELT(typeArg, 0)), "within")) type = WITHIN;
   else if (!strcmp(CHAR(STRING_ELT(typeArg, 0)), "start")) type = START;
   else if (!strcmp(CHAR(STRING_ELT(typeArg, 0)), "end")) type = END;
   else if (!strcmp(CHAR(STRING_ELT(typeArg, 0)), "equal")) type = EQUAL;
-  else error("Internal error: invalid value for 'type'; this should have been caught before. please report to data.table issue tracker"); // # nocov
+  else error(_("Internal error: invalid value for 'type'; this should have been caught before. please report to data.table issue tracker")); // # nocov
 
   // For reference: uxcols-1 = type_count, uxcols-2 = count, uxcols-3 = type_lookup, uxcols-4 = lookup
   // first pass: calculate lengths first
@@ -53,7 +53,7 @@ SEXP lookup(SEXP ux, SEXP xlen, SEXP indices, SEXP gaps, SEXP overlaps, SEXP mul
           if (count[i]) type_count[i] = 1;
       }
       break;
-    default: error("Internal error: unknown type in mult=%d in lookup: %d", mult, type); // #nocov
+    default: error(_("Internal error: unknown type in mult=%d in lookup: %d"), mult, type); // #nocov
     }
     break;
 
@@ -118,14 +118,14 @@ SEXP lookup(SEXP ux, SEXP xlen, SEXP indices, SEXP gaps, SEXP overlaps, SEXP mul
         }
       }
       break;
-    default: error("Internal error: unknown type in mult=%d in lookup: %d", mult, type); // #nocov
+    default: error(_("Internal error: unknown type in mult=%d in lookup: %d"), mult, type); // #nocov
     }
     break;
-  default: error("Internal error: unknown mult in lookup: %d", mult); // #nocov
+  default: error(_("Internal error: unknown mult in lookup: %d"), mult); // #nocov
   }
   pass1 = clock() - start;
   if (LOGICAL(verbose)[0])
-    Rprintf("First pass on calculating lengths in lookup ... done in %8.3f seconds\n", 1.0*(pass1)/CLOCKS_PER_SEC);
+    Rprintf(_("First pass on calculating lengths in lookup ... done in %8.3f seconds\n"), 1.0*(pass1)/CLOCKS_PER_SEC);
   // second pass: allocate vectors
   start = clock();
   lookup = VECTOR_ELT(ux, uxcols-4);
@@ -138,7 +138,7 @@ SEXP lookup(SEXP ux, SEXP xlen, SEXP indices, SEXP gaps, SEXP overlaps, SEXP mul
   }
   pass2 = clock() - start;
   if (LOGICAL(verbose)[0])
-    Rprintf("Second pass on allocation in lookup ... done in %8.3f seconds\n", 1.0*(pass2)/CLOCKS_PER_SEC);
+    Rprintf(_("Second pass on allocation in lookup ... done in %8.3f seconds\n"), 1.0*(pass2)/CLOCKS_PER_SEC);
   // generate lookup
   start = clock();
   idx = Calloc(uxrows, R_len_t); // resets bits, =0
@@ -157,7 +157,7 @@ SEXP lookup(SEXP ux, SEXP xlen, SEXP indices, SEXP gaps, SEXP overlaps, SEXP mul
       INTEGER(VECTOR_ELT(lookup, to[i]-1))[idx[to[i]-1]++] = i+1;
     }
     break;
-  default: error("Internal error: unknown type lookup should have been caught earlier: %d", type); // #nocov
+  default: error(_("Internal error: unknown type lookup should have been caught earlier: %d"), type); // #nocov
   }
   Free(idx);
   // generate type_lookup
@@ -209,15 +209,15 @@ SEXP lookup(SEXP ux, SEXP xlen, SEXP indices, SEXP gaps, SEXP overlaps, SEXP mul
         //         INTEGER(tt)[j] = INTEGER(vv)[j];
         // }
         break; // #nocov
-      default: error("Internal error: unknown type in mult=%d in lookup should have been caught earlier: %d", mult, type); // #nocov
+      default: error(_("Internal error: unknown type in mult=%d in lookup should have been caught earlier: %d"), mult, type); // #nocov
       }
      break;
-    default: error("Internal error: unknown mult in lookup: %d", mult); // #nocov
+    default: error(_("Internal error: unknown mult in lookup: %d"), mult); // #nocov
     }
   }
   pass3 = clock() - start;
   if (LOGICAL(verbose)[0])
-    Rprintf("Final step in generating lookup ... done in %8.3f seconds\n", 1.0*(pass3)/CLOCKS_PER_SEC);
+    Rprintf(_("Final step in generating lookup ... done in %8.3f seconds\n"), 1.0*(pass3)/CLOCKS_PER_SEC);
   return(R_NilValue);
 }
 
@@ -240,14 +240,14 @@ SEXP overlaps(SEXP ux, SEXP imatches, SEXP multArg, SEXP typeArg, SEXP nomatchAr
   if (!strcmp(CHAR(STRING_ELT(multArg, 0)), "all"))  mult = ALL;
   else if (!strcmp(CHAR(STRING_ELT(multArg, 0)), "first")) mult = FIRST;
   else if (!strcmp(CHAR(STRING_ELT(multArg, 0)), "last")) mult = LAST;
-  else error("Internal error: invalid value for 'mult'; this should have been caught before. please report to data.table issue tracker"); // # nocov
+  else error(_("Internal error: invalid value for 'mult'; this should have been caught before. please report to data.table issue tracker")); // # nocov
 
   if (!strcmp(CHAR(STRING_ELT(typeArg, 0)), "any"))  type = ANY;
   else if (!strcmp(CHAR(STRING_ELT(typeArg, 0)), "within")) type = WITHIN;
   else if (!strcmp(CHAR(STRING_ELT(typeArg, 0)), "start")) type = START;
   else if (!strcmp(CHAR(STRING_ELT(typeArg, 0)), "end")) type = END;
   else if (!strcmp(CHAR(STRING_ELT(typeArg, 0)), "equal")) type = EQUAL;
-  else error("Internal error: invalid value for 'type'; this should have been caught before. please report to data.table issue tracker"); // # nocov
+  else error(_("Internal error: invalid value for 'type'; this should have been caught before. please report to data.table issue tracker")); // # nocov
 
   // As a first pass get the final length, so that we can allocate up-front and not deal with Calloc + Realloc + size calculation hassle
   // Checked the time for this loop on realisitc data (81m reads) and took 0.27 seconds! No excuses ;).
@@ -320,12 +320,12 @@ SEXP overlaps(SEXP ux, SEXP imatches, SEXP multArg, SEXP typeArg, SEXP nomatchAr
           ++totlen;
       }
       break;
-    default: error("Internal error: unknown type in mult=ALL in overlaps: %d", mult, type); // #nocov
+    default: error(_("Internal error: unknown type in mult=ALL in overlaps: %d"), mult, type); // #nocov
     }
   } else totlen = rows;
   end1 = clock() - start;
   if (LOGICAL(verbose)[0])
-    Rprintf("First pass on calculating lengths in overlaps ... done in %8.3f seconds\n", 1.0*(end1)/CLOCKS_PER_SEC);
+    Rprintf(_("First pass on calculating lengths in overlaps ... done in %8.3f seconds\n"), 1.0*(end1)/CLOCKS_PER_SEC);
 
   // ans[0] is the the position of 'query' and ans[1] is that of 'subject'
   // allocate f1__ and f2__ and assign 'nomatch' to f2__
@@ -461,7 +461,7 @@ SEXP overlaps(SEXP ux, SEXP imatches, SEXP multArg, SEXP typeArg, SEXP nomatchAr
          }
       }
       break;
-    default: error("Internal error: unknown type in mult=%d in overlaps: %d", mult, type); // #nocov
+    default: error(_("Internal error: unknown type in mult=%d in overlaps: %d"), mult, type); // #nocov
     }
     break;
 
@@ -568,7 +568,7 @@ SEXP overlaps(SEXP ux, SEXP imatches, SEXP multArg, SEXP typeArg, SEXP nomatchAr
         }
       }
       break;
-    default: error("Internal error: unknown type in mult=%d in overlaps: %d", mult, type); // #nocov
+    default: error(_("Internal error: unknown type in mult=%d in overlaps: %d"), mult, type); // #nocov
     }
     break;
 
@@ -717,14 +717,14 @@ SEXP overlaps(SEXP ux, SEXP imatches, SEXP multArg, SEXP typeArg, SEXP nomatchAr
          }
       }
       break;
-    default: error("Internal error: unknown type in mult=%d in overlaps: %d", mult, type); // #nocov
+    default: error(_("Internal error: unknown type in mult=%d in overlaps: %d"), mult, type); // #nocov
     }
     break;
-  default: error("Internal error: unknown mult in overlaps: %d", mult); // #nocov
+  default: error(_("Internal error: unknown mult in overlaps: %d"), mult); // #nocov
   }
   end2 = clock() - start;
   if (LOGICAL(verbose)[0])
-    Rprintf("Final step, fetching indices in overlaps ... done in %8.3f seconds\n", 1.0*(end2)/CLOCKS_PER_SEC);
+    Rprintf(_("Final step, fetching indices in overlaps ... done in %8.3f seconds\n"), 1.0*(end2)/CLOCKS_PER_SEC);
   UNPROTECT(1);
   return(ans);
 }
